Weblate
=======

.. image:: https://travis-ci.org/WeblateOrg/weblate.svg
    :alt: Build status
    :target: https://travis-ci.org/WeblateOrg/weblate

.. image:: https://ci.appveyor.com/api/projects/status/92elnra2etjgfpc8/branch/master?svg=true
    :target: https://ci.appveyor.com/project/nijel/weblate/branch/master
    :alt: Build status

.. image:: https://hosted.weblate.org/widgets/weblate/-/svg-badge.svg
    :alt: Translation status
    :target: https://hosted.weblate.org/engage/weblate/?utm_source=widget

.. image:: https://codecov.io/gh/WeblateOrg/weblate/branch/master/graph/badge.svg
    :alt: Codecov Coverage Status
    :target: https://codecov.io/gh/WeblateOrg/weblate

.. image:: https://landscape.io/github/WeblateOrg/weblate/master/landscape.png
    :alt: Code Health
    :target: https://landscape.io/github/WeblateOrg/weblate/master

.. image:: https://api.codacy.com/project/badge/Grade/394a22d396414d48abb6a85054f4415e
    :alt: Codacy Badge
    :target: https://www.codacy.com/app/Weblate/weblate

.. image:: https://api.bountysource.com/badge/tracker?tracker_id=253393
    :alt: Bountysource
    :target: https://www.bountysource.com/trackers/253393-weblate?utm_source=253393&utm_medium=shield&utm_campaign=TRACKER_BADGE

.. image:: https://bestpractices.coreinfrastructure.org/projects/552/badge
    :alt: CII Best Practices
    :target: https://bestpractices.coreinfrastructure.org/projects/552

.. image:: https://img.shields.io/pypi/v/Weblate.svg
    :target: https://pypi.org/project/Weblate/

.. image:: https://www.codetriage.com/weblateorg/weblate/badges/users.svg
    :target: https://www.codetriage.com/weblateorg/weblate

.. image:: https://img.shields.io/badge/docs-latest-brightgreen.svg?style=flat
    :alt: Documentation
    :target: https://docs.weblate.org/

Weblate is a free web-based translation tool with tight version control
integration. It features simple and clean user interface, propagation of
translations across components within a project, quality checks and automatic
linking to source files.

Weblate has its website at https://weblate.org/.

Features
--------

* Easy web based translation
* Propagation of translations across components (eg. branches) within projects
* Tight VCS integration - every change is represented by version control commit
* Usage of Django's admin interface
* Upload and automatic merging of po files
* Links to source files for context
* Message quality checks
* Tunable access control
* Wide range of supported translation formats (Gettext, Qt, Java, Windows, Symbian and more)
* Supports Git and Mercurial

Documentation
-------------

Detailed documentation is available in ``docs`` directory in the sources.

The documentation can be also viewed online on
https://docs.weblate.org/.

Installation
------------

Installation and setup instructions are provided in our manual, check
quick setup guide:

https://docs.weblate.org/en/latest/admin/quick.html

Bugs
----

Please report bugs to https://github.com/WeblateOrg/weblate/issues.

License
-------

Copyright (C) 2012 - 2018 Michal Čihař michal@cihar.com

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see https://www.gnu.org/licenses/.
